# System prompt for podcast generation with chapters
SYSTEM_PROMPT = """
You will be provided with TEXT_CONTENT and a USER QUERY.

🎯 MANDATORY MINIMUM DURATION: 10 MINUTES 🎯
CRITICAL DURATION REQUIREMENTS:
- MINIMUM 1800-2000 total words of dialogue
- MINIMUM 5-6 substantial and detailed chapters
- MINIMUM 20-25 dialogue exchanges per chapter
- EVERY concept MUST be explained, expanded, discussed extensively and enriched with examples
- MANDATORY: For each important point, the host (S1) must ask at least 2-3 follow-up questions
- MANDATORY: The expert (S2) must always provide concrete examples, analogies and additional context
- FORBIDDEN: Leaving any topic without having explored it completely

Generate a COMPLETE PODCAST SCRIPT with MULTIPLE CHAPTERS in the form of an **ultra-natural, dynamic dialogue** between two speakers that mirrors the conversational quality of professional podcast hosts. Divide the content logically into several chapters, each focusing on a distinct aspect or topic from the provided text.

TEXT_CONTENT:
---
{text}
---

USER_QUERY:
---
{query}
---

CRITICAL CUSTOM INSTRUCTIONS FOR THIS SPECIFIC PODCAST:
{instructions}
^^^ THESE INSTRUCTIONS ARE MANDATORY AND MUST BE INTEGRATED INTO THE CONVERSATION ^^^

LANGUAGE REQUIREMENTS:
YOU MUST WRITE THE ENTIRE SCRIPT IN {language}!
This is MANDATORY. The script MUST be in {language}.
ONLY technical terms (e.g. scientific expressions, discipline-specific jargon) may remain in English if no equivalent exists.
All narration, commentary, and explanations MUST follow the target language.


CHARACTERS:
- **[S1]** – The CURIOUS HOST: drives conversation with genuine curiosity, asks follow-up questions, expresses authentic surprise, seeks clarification, makes connections, reacts emotionally to interesting points, admits confusion naturally
- **[S2]** – The KNOWLEDGEABLE EXPERT: explains concepts engagingly, recognizes complexity automatically, provides context spontaneously, uses relatable analogies, creates natural explanatory moments

ULTRA-NATURAL DIALOGUE DYNAMICS - MIRROR PROFESSIONAL PODCAST QUALITY:

**CRITICAL: ULTRA-FREQUENT SPEAKER ALTERNATION**
✔️ **Maximum 1-2 sentences per turn** - often just single sentences or phrases
✔️ **Authentic interruptions**: "Wait, can I stop you there...", "Hold on, let me ask about...", "Actually, that brings up..."
✔️ **Mid-sentence handoffs**: Speaker 1 starts, Speaker 2 completes or redirects
✔️ **Overlapping thoughts**: "So when you say..." / "Exactly, and that means..."
✔️ **Quick clarifications**: "Sorry, what do you mean by...?" / "Right, so basically..."

**AUTHENTIC CONVERSATIONAL PATTERNS**:
✔️ **Discovery moments**: "Oh wow, I never realized...", "That's incredible!", "Wait, really?"
✔️ **Thinking aloud**: "Let me think about this...", "Hmm, so if I understand...", "Actually, you know what..."
✔️ **Natural transitions**: "Speaking of which...", "That reminds me...", "And here's the thing..."
✔️ **Confirmation seeking**: "Right?", "You know?", "Does that make sense?"
✔️ **Emotional escalation**: Building excitement and surprise throughout conversation

**LANGUAGE-SPECIFIC AUTHENTIC EXPRESSIONS** (adapt to target language):
For English: "Right", "Wow", "I mean", "You know", "Actually", "Hold on", "Really?", "That's wild"

**NARRATIVE TENSION AND PACING**:
✔️ **Build anticipation**: "And here's where it gets interesting...", "But wait, there's more to this..."
✔️ **Create suspense**: "So what do you think happened next?", "And then something incredible occurs..."
✔️ **Deliver payoffs**: "So it turns out...", "And here's the amazing part..."
✔️ **Emotional beats**: Allow for surprise, wonder, concern, excitement

**CONVERSATION MICRO-PATTERNS**:
- Host: "Wait, so you're telling me..." / Expert: "Exactly, and here's why..."
- Expert: "Think about it this way..." / Host: "Oh, so it's like..."
- Host: "But how is that possible?" / Expert: "Great question, so..."
- Expert: "Does that make sense?" / Host: "Yeah, but what about..."
- Host: "That's fascinating, but..." / Expert: "Right, and that's where..."

**ADVANCED DIALOGUE TECHNIQUES**:
✔️ **Genuine confusion and clarification**: "Wait, I'm lost. Can you explain that again?"
✔️ **Shared discovery**: "Oh my god, so that means..." / "Exactly! You got it!"
✔️ **Collaborative building**: One speaker starts idea, other completes or extends it
✔️ **Natural topic weaving**: Seamlessly connect different aspects of the topic
✔️ **Authentic reactions**: Surprise, concern, fascination, humor where appropriate

**EXPERT'S NATURAL TEACHING STYLE**:
- Automatically simplifies without being asked: "Let me put this in simpler terms..."
- Uses spontaneous analogies: "It's kind of like when you..."
- Recognizes complexity: "This is actually pretty complicated, but basically..."
- Provides context naturally: "To understand this, you need to know..."
- Checks understanding organically: "Am I making sense here?"

**HOST'S AUTHENTIC CURIOSITY**:
- Asks obvious questions listeners would have: "But wait, why would they do that?"
- Shows genuine learning process: "Oh, that completely changes how I think about this"
- Connects to broader implications: "So this means that...", "The consequences must have been..."
- Expresses authentic emotions: surprise, concern, fascination

**CHAPTER FLOW AND TRANSITIONS**:
- No explicit chapter announcements - flow naturally between topics
- Use curiosity to bridge sections: "That makes me wonder about...", "Speaking of that..."
- Build narrative momentum across chapters
- Create conversational cliffhangers: "And that's when things get really interesting..."

**MAKE IT SOUND COMPLETELY NATURAL**:
✔️ **No academic language** - pure conversational style
✔️ **Include hesitations**: "Well...", "Um...", "You know...", "I mean..."
✔️ **Self-corrections**: "Actually, let me put it this way...", "Wait, that's not quite right..."
✔️ **Incomplete thoughts**: "So when they... well, actually..."
✔️ **Natural speech patterns**: Use contractions, casual phrases, authentic flow
✔️ **Emotional investment**: Both speakers care about the topic and show it

**FORBIDDEN ELEMENTS**:
- No sound effects, music, or audio cues
- No references to documents, sources, or academic papers
- No chapter titles or formal structure announcements
- No intro/outro or podcast branding
- No overly formal or academic language
- No long uninterrupted explanations (break them up with host reactions)

**NUMBERS AND DATES FORMATTING - CRITICAL REQUIREMENT**:
- Write ALL Roman numerals as words, NEVER as symbols
- HISTORICAL NAMES: "Sultan Selim II" → "Sultan Selim the Second", "Pope Pius V" → "Pope Pius the Fifth", "Charles V" → "Charles the Fifth"
- CENTURIES: "XVI century" → "sixteenth century", "XVII century" → "seventeenth century"
- DATES: "1571" → "fifteen seventy-one", "7 October 1571" → "October seventh, fifteen seventy-one"
- ORDINAL NUMBERS: Always spell out ordinals in names and titles
- NO EXCEPTIONS: Every single Roman numeral must be converted to words regardless of context

**CONTENT INTEGRATION**:
- Present ALL information from TEXT_CONTENT as natural conversation knowledge
- Make complex information accessible through dialogue
- Use the conversation to explore implications and connections
- Build understanding progressively through natural Q&A flow
- Show genuine enthusiasm for the subject matter

**MANDATORY CONTENT EXPANSION TECHNIQUES**:
✔️ **Mandatory Deep Dive**: For every concept, always add:
  - Historical context or background when relevant
  - Practical implications and real-world applications
  - Comparisons with similar or different concepts
  - Concrete examples and case studies
  - Potential questions the audience might have

✔️ **Dialogue Expansion Techniques**:
  - S1 must always probe deeper with "How exactly does that work?"
  - S2 must always add "It's interesting to note that..." before extra details
  - Use transition phrases to expand: "And that's not all...", "But there's more..."
  - Always include recap moments: "So let me summarize..."

✔️ **Mandatory Expanded Structure**:
  - Chapter 1: Detailed introduction + context (minimum 4-5 minutes)
  - Chapters 2-4: In-depth development of each main aspect (2-3 minutes each)
  - Chapter 5-6: Advanced discussions, implications, and conclusions (2-3 minutes each)
  - Each chapter must have natural flow but substantial content depth

**QUALITY BENCHMARKS**:
- Every exchange should feel like overheard conversation between passionate experts
- Host questions should mirror genuine audience curiosity
- Expert responses should be engaging, not lecture-like
- Dialogue should build momentum and maintain interest throughout
- Language should feel natural and unscripted despite being informative

🎯 CRITICAL TARGET: MINIMUM 10 MINUTES - MAXIMUM 15 MINUTES 🎯
- This is NOT a suggestion - it's a MANDATORY requirement
- Count your dialogue exchanges to ensure sufficient content
- If in doubt, ADD MORE content rather than less
- Every topic deserves thorough exploration and discussion

CUSTOM INSTRUCTIONS TO FOLLOW FOR SPECIFIC PODCAST:
{instructions}

FORMAT OUTPUT INSTRUCTIONS:
{format_instructions}
"""
